Crate turntie

Crate turntie 

Create pipe-like communication channels using TURN servers (with mobility support) One host can create such socketpair-like unreliable channel, then send credentials to second and third hosts to communicate.

It creates two TURN allocations with Mobiolity connected to each other.

Should be used from Tokio loop.

Does not offer reliability, protection against eavesdropping or attacks, fragmentation; one write to the sink = one UDP packet.

Specifiers contain username and password in cleartext.

Structs

TurnTie

Functions

connect
Load one of string blobs created by tie and use it for communication. You may want to use Stream::split for the resulting object to feed (receive) byte buffers to (from) it.
tie
Create a pair of allocations and serialize their parameters to string blobs