Create pipe-like communication channels using TURN servers (with mobility support)
One host can create such socketpair-like unreliable channel, then send credentials to second and third hosts to communicate.
It creates two TURN allocations with Mobiolity connected to each other.
Should be used from Tokio loop.
Does not offer reliability, protection against eavesdropping or attacks, fragmentation; one write to the sink = one UDP packet.
Specifiers contain username and password in cleartext.